@@ -38,14 +38,18 @@
 #' @param conf.level a numeric value between 0 and 1 specifying the
 #'   confidence level (i.e., 1 - audit risk / detection risk).
 #' @param prior      a logical specifying whether to use a prior distribution,
-#'   or a numeric vector containing the prior parameters for the Dirichlet
-#'   distribution on the digit categories.
+#'   or a numeric value equal to or larger than 1 specifying the prior
+#'   concentration parameter, or a numeric vector containing the prior
+#'   parameters for the Dirichlet distribution on the digit categories.
 #'
 #' @details Benford's law is defined as \eqn{p(d) = log10(1/d)}. The uniform
 #'   distribution is defined as \eqn{p(d) = 1/d}.
 #'
 #' @return An object of class \code{jfaDistr} containing:
 #'
+#' \item{data}{the specified data.}
+#' \item{conf.level}{a numeric value between 0 and 1 giving the confidence
+#'   level.}
 #' \item{observed}{the observed counts.}
 #' \item{expected}{the expected counts under the null hypothesis.}
 #' \item{n}{the number of observations in \code{x}.}
@@ -58,6 +62,9 @@
 #' \item{reference}{reference distribution}
 #' \item{match}{a list containing the row numbers corresponding to the
 #'   observations matching each digit.}
+#' \item{deviation}{a vector indicating which digits deviate from their
+#'   expected relative frequency under the reference distribution.}
+#' \item{prior}{a logical indicating whether a prior distribution was used.}
 #' \item{data.name}{a character string giving the name(s) of the data.}
 #'
 #' @author Koen Derks, \email{k.derks@nyenrode.nl}
@@ -134,21 +141,17 @@ digit_test <- function(x,
     names(statistic) <- "X-squared"
     names(parameter) <- "df"
   } else {
-    if (is.logical(prior)) {
-      alpha <- rep(1, length(dig))
-    } else if (length(prior) != length(dig)) {
+    if (isTRUE(prior)) {
+      prior_vec <- rep(1, length(dig))
+    } else if (is.numeric(prior) && length(prior) == 1) {
+      stopifnot("'prior' must be a numeric value >= 1" = prior >= 1)
+      prior_vec <- rep(prior, length(dig))
+    } else if (is.numeric(prior) && length(prior) != length(dig)) {
       stop("number of elements in 'prior' must be equal to number of digits")
     } else {
-      alpha <- prior
+      prior_vec <- prior
     }
-    lbeta_xa <- sum(lgamma(alpha + obs)) - lgamma(sum(alpha + obs))
-    lbeta_a <- sum(lgamma(alpha)) - lgamma(sum(alpha))
-    if (any(rowSums(cbind(p_exp, obs)) == 0)) {
-      log_bf10 <- (lbeta_xa - lbeta_a)
-    } else {
-      log_bf10 <- (lbeta_xa - lbeta_a) + (0 - sum(obs * log(p_exp)))
-    }
-    bf <- exp(log_bf10)
+    bf <- .multinomialBf(obs, p_exp, prior_vec)
     names(bf) <- "BF10"
   }
   mad <- mean(abs((obs / n) - (exp / n)))
@@ -157,6 +160,7 @@ digit_test <- function(x,
   names(obs) <- dig
   names(exp) <- dig
   result <- list()
+  result[["data"]] <- x
   result[["conf.level"]] <- conf.level
   result[["observed"]] <- obs
   result[["expected"]] <- exp
@@ -186,6 +190,7 @@ digit_test <- function(x,
   deviation <- result[["estimates"]]$p.exp <= result[["estimates"]]$lb | result[["estimates"]]$p.exp >= result[["estimates"]]$ub
   names(deviation) <- dig
   result[["deviation"]] <- deviation
+  result[["prior"]] <- prior
   result[["data.name"]] <- dname
   class(result) <- c("jfaDistr", "list")
   return(result)
